==> haskell-turtle-1.5.14-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.5.14
id: turtle-1.5.14-CcTd5MAac0v2MCFZKSEapQ
key: turtle-1.5.14-CcTd5MAac0v2MCFZKSEapQ
license: BSD-3-Clause
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
abi: 5216e970e65e2c916e1fe4f285497508
exposed: True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/turtle-1.5.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/turtle-1.5.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/turtle-1.5.14
hs-libraries: HSturtle-1.5.14-CcTd5MAac0v2MCFZKSEapQ
depends:
    ansi-wl-pprint-0.6.9-8GHEGH1lUTqAkRwSafnocf
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 clock-0.8-H1S1zDefxirImaRbI6ITNv
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-D9MYzhqXvqCL8hMQL1PEiN
    foldl-1.4.5-6l3rwMO9lYtE0MlEec9JOe
    hostname-1.0-96RwzZJKf0mHYnt0kjXkqR
    managed-1.0.6-6le630bw4rn2FNayf9Wk9z
    optional-args-1.0.2-1m715yvjsnq8LooJByzcqK
    optparse-applicative-0.14.3.0-2TcXyk5noJJ9JcSai3IjVr
    process-1.6.5.0 stm-2.5.0.0
    system-fileio-0.3.16.4-HlRuLFEUs5510FaMgZTWEJ
    system-filepath-0.4.14-FRUtJu5zAWTG9MKrRBz8D6
    temporary-1.3-86OIviHidbW4076q5ChbcH text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-turtle-1.5.14-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.5.14
id: turtle-1.5.14-IB3lV4y0MrIAnsvtD8AeJZ
key: turtle-1.5.14-IB3lV4y0MrIAnsvtD8AeJZ
license: BSD-3-Clause
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
abi: 2223d4bb80d0cd9d0d5eceb7daf9ba5c
exposed: True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/turtle-1.5.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/turtle-1.5.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/turtle-1.5.14
hs-libraries: HSturtle-1.5.14-IB3lV4y0MrIAnsvtD8AeJZ
depends:
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 clock-0.8-H1S1zDefxirImaRbI6ITNv
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F
    foldl-1.4.5-NnAc6Tf1N59HW5MKU8Pwu
    hostname-1.0-96RwzZJKf0mHYnt0kjXkqR
    managed-1.0.6-6le630bw4rn2FNayf9Wk9z
    optional-args-1.0.2-1m715yvjsnq8LooJByzcqK
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    process-1.6.5.0 stm-2.5.0.0
    system-fileio-0.3.16.4-HlRuLFEUs5510FaMgZTWEJ
    system-filepath-0.4.14-FRUtJu5zAWTG9MKrRBz8D6
    temporary-1.3-CFCgitssjB1JHRoe7RSBPx text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
